# -*- coding: utf-8 -*-
import sys

from setuptools import setup
from setuptools.command.test import test as TestCommand

requires = ['click', 'boto3']
tests_require = ['pytest', 'pytest-cache', 'pytest-cov']
dev_require = ['tox', 'bumpversion', 'twine']


class PyTest(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        # import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.test_args)
        sys.exit(errno)


setup(
    name="will-iam",
    version='0.1.0',
    description="",
    long_description="\n\n".join([open("README.rst").read()]),
    license=open('LICENSE').read(),
    author="Sebastian Vetter",
    author_email="seb@roadsi.de",
    url="https://will-iam.readthedocs.org",
    packages=['will_iam'],
    install_requires=requires,
    entry_points={'console_scripts': [
        'will.iam = will_iam.cli:main']},
    classifiers=[
        'Development Status :: 1 - Planning',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: Implementation :: CPython'],
    extras_require={'test': tests_require,
                    'dev': tests_require + dev_require},
    cmdclass={'test': PyTest})
