# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function
import os
import click

from boto3 import session

from . import policies


AWS_ACCESS_KEY_ID = os.getenv('AWS_ACCESS_KEY_ID')
AWS_SECRET_ACCESS_KEY = os.getenv('AWS_SECRET_ACCESS_KEY')


@click.group()
@click.option('--region', default='us-east-1')
@click.option('--profile', default=None)
@click.option('--aws-access-key', default=AWS_ACCESS_KEY_ID)
@click.option('--aws-secret-key', default=AWS_SECRET_ACCESS_KEY)
@click.option('--profile', default=None)
@click.pass_context
def main(ctx, region, profile, aws_access_key, aws_secret_key):
    boto_session = session.Session(aws_access_key_id=aws_access_key,
                                   aws_secret_access_key=aws_secret_key,
                                   profile_name=profile,
                                   region_name=region)

    ctx.obj = {'region': region,
               'boto': boto_session}


@main.group()
@click.pass_context
def policy(ctx):
    pass


@policy.command()
@click.option('--all', default=False, is_flag=True)
@click.pass_context
def list(ctx, all):
    boto_session = ctx.obj['boto']

    scope = 'Local'
    if all:
        scope = 'All'

    for policy in policies.policies(boto_session, scope):
        print(policy.get('PolicyName'))


@policy.command()
@click.option('--dirname', default='policies')
@click.pass_context
def export(ctx, dirname):
    boto_session = ctx.obj['boto']

    if not os.path.exists(dirname):
        os.makedirs(dirname)

    for policy in policies.policies(boto_session):
        policy_name = policy.get('PolicyName')
        policy_arn = policy.get('Arn')

        filename = '{}/{}.json'.format(dirname, policy_name)

        policies.export_policy(boto_session, policy_arn, filename)

        click.secho('Exported policy {}'.format(policy_name), fg='green')
